pub struct DenseArray<N> { /* private fields */ }Expand description
A materialized 3-dimensional array containing the burned geometries and spatial information.
Implementations
Sourceimpl<N: Num> DenseArray<N>
impl<N: Num> DenseArray<N>
Sourcepub fn into_parts(self) -> (Array3<N>, Vec<String>, RasterInfo)
pub fn into_parts(self) -> (Array3<N>, Vec<String>, RasterInfo)
Consume self and extract all fields of the DenseArray.
Sourcepub fn band_names(&self) -> &[String]
pub fn band_names(&self) -> &[String]
Sorted band names for the array. Defaults to “band_1” for a single band.
Sourcepub fn raster_info(&self) -> &RasterInfo
pub fn raster_info(&self) -> &RasterInfo
Spatial information associated with the array.