pub struct RasterInfoBuilder { /* private fields */ }Expand description
Builder for a RasterInfo instance.
If extent is not provided, it can be inferred from the geo::Geometry when building it.
In this case, a half-pixel buffer is applied to avoid missing points on the border.
The logics dictating the final spatial properties of the rasterized geometries follow those of GDAL.
Implementations
Sourceimpl RasterInfoBuilder
impl RasterInfoBuilder
pub fn new() -> Self
Sourcepub fn build(self) -> RusterizeResult<RasterInfo>
pub fn build(self) -> RusterizeResult<RasterInfo>
Build into a RasterInfo with user-defined extent.
Sourcepub fn build_with(self, geoms: &[Geometry<f64>]) -> RusterizeResult<RasterInfo>
pub fn build_with(self, geoms: &[Geometry<f64>]) -> RusterizeResult<RasterInfo>
Same as build, but infer extent from the geometry.
pub fn shape(self, nrows: usize, ncols: usize) -> Self
pub fn extent(self, xmin: f64, ymin: f64, xmax: f64, ymax: f64) -> Self
pub fn resolution(self, xres: f64, yres: f64) -> Self
pub fn with_target_align_pixel(self) -> Self
pub fn epsg(self, epsg: u16) -> Self