pub struct RasterizeContext<'a, N> {
pub raster_info: RasterInfo,
pub field: FieldSource<'a, N>,
pub by: Option<&'a [String]>,
pub pixel_fn: PixelFunction,
pub background: N,
pub all_touched: bool,
}Expand description
Spatial + value context handed to the rasterization engine.
Fields
raster_info: RasterInfoThe spatial information of the final raster.
field: FieldSource<'a, N>The values to burn.
by: Option<&'a [String]>Specify the grouping of the geometries into multiple bands in the final raster. None is no grouping.
For this to work, by has to have the same length of the geometries.
pixel_fn: PixelFunctionDescribes what happens to overlapping pixels.
background: Nall_touched: boolFlags whether all pixels touching the geometry should be burned.