RasterizeContext

Struct RasterizeContext 

pub struct RasterizeContext<'a, N> {
    pub raster_info: RasterInfo,
    pub field: FieldSource<'a, N>,
    pub by: Option<&'a [String]>,
    pub pixel_fn: PixelFunction,
    pub background: N,
    pub all_touched: bool,
}
Spatial + value context handed to the rasterization engine.

Fields

raster_info: RasterInfo

The spatial information of the final raster.

field: FieldSource<'a, N>

The values to burn.

by: Option<&'a [String]>

Specify the grouping of the geometries into multiple bands in the final raster. None is no grouping. For this to work, by has to have the same length of the geometries.

pixel_fn: PixelFunction

Describes what happens to overlapping pixels.

background: Nall_touched: bool

Flags whether all pixels touching the geometry should be burned.